@@ -67,7 +67,7 @@ fact.numeric <- function(x) {
     u <- u[-length(u)]
   }
 
-  x[is.nan(x)] <- NA_real_
+  x[is.nan(x)] <- NA
   new_fact(match(x, u), u)
 }
 
@@ -128,7 +128,6 @@ fact.factor <- function(x) {
     return(res)
   }
 
-
   if (anyNA(x) || anyNA(old_levels)) {
     new_levels <-
       if (!anyNA(new_levels)) {
@@ -169,41 +168,81 @@ fact.pseudo_id <- function(x) {
 #' @export
 fact.haven_labelled <- function(x) {
   require_namespace("haven")
-  labels <- sort(attr(x, "labels", exact = TRUE))
-  uc <- unclass(x)
-  u <- unique(uc)
-  m <- match(u, labels)
-  nas <- is.na(m)
+  lvls <- attr(x, "labels")
 
-  if (any(nas)) {
-    # Done to match haven::as_factor.haven_labelled()
-    labels <- labels[m]
-    labels[nas] <- u[nas]
-    names(labels)[nas] <- u[nas]
-    mx <- match(x, labels)
+  if (length(lvls)) {
+    ux <- unclass(x)
+    uniques <- sort.int(unique(c(ux, lvls)))
+    m <- match(ux, uniques)
+    ml <- match(lvls, uniques)
+    uniques[ml] <- names(lvls)
+    res <- new_fact(m, uniques)
   } else {
-    mx <- as.integer(x)
+    res <- fact(unclass(x))
   }
 
-  struct(
-    mx,
-    class = c("fact", "factor"),
-    levels = names(labels),
-    label = attr(x, "label", exact = TRUE)
-  )
+  attr(res, "label") <- exattr(x, "label")
+  res
 }
 
 #' @export
-print.fact <- function(x, ...) {
-  out <- x
-  attr(out, "uniques") <- NULL
-  attr(out, "na") <- NULL
-  class(out) <- class(out) %wo% "fact"
-  print(out)
+print.fact <- function(
+  x,
+  max_levels = getOption("mark.fact.max_levels", TRUE),
+  width = getOption("width"),
+  ...
+) {
+  # mostly a reformatted base::print.factor()
+  ord <- is.ordered(x)
+  if (length(x) == 0L) {
+    cat(if (ord) "ordered" else "factor", "(0)\n", sep = "")
+  } else {
+    print(as.character(x), quote = FALSE, ...)
+  }
+
+  if (max_levels) {
+    lev <- encodeString(levels(x), quote = "")
+    n <- length(lev)
+    colsep <- if (ord) " < " else " "
+    T0 <- "Levels: "
+    if (is.logical(max_levels)) {
+      max_levels <- {
+        width <- width - (nchar(T0, "w") + 3L +  1L + 3L)
+        lenl <- cumsum(nchar(lev, "w") + nchar(colsep, "w"))
+
+        if (n <= 1L || lenl[n] <= width) {
+          n
+        } else {
+          max(1L, which.max(lenl > width) - 1L)
+        }
+      }
+    }
+    drop <- n > max_levels
+    cat(
+      if (drop) paste(format(n), ""),
+      T0,
+      paste(
+        if (drop) {
+          c(lev[1L:max(1, max_levels - 1)], "...", if (max_levels >  1) lev[n])
+        } else {
+          lev
+        },
+        collapse = colsep
+      ),
+      "\n",
+      sep = ""
+    )
+
+    # Be nice to haven_labelled
+    lab <- exattr(x, "label")
+    if (!is.null(lab)) {
+      cat("Label: ", paste(format(lab), ""), "\n", sep = "")
+    }
+  }
+
   invisible(x)
 }
 
-
 # as_ordered --------------------------------------------------------------
 
 #' Ordered
@@ -240,7 +279,6 @@ as_ordered <- function(x) {
   UseMethod("as_ordered", x)
 }
 
-
 #' @rdname as_ordered
 #' @export
 as_ordered.default <- function(x) {
@@ -254,7 +292,6 @@ as_ordered.default <- function(x) {
 }
 
 
-
 # drop_levels -------------------------------------------------------------
 
 #' Drop levels
@@ -264,6 +301,7 @@ as_ordered.default <- function(x) {
 #' @param x A `factor` or `data.frame`
 #' @param ... Additional arguments passed to methods (not used)
 #' @seealso [base::droplevels]
+#' @export
 #' @family factors
 drop_levels <- function(x, ...) {
   UseMethod("drop_levels", x)
@@ -277,18 +315,6 @@ drop_levels.data.frame <- function(x, ...) {
   x
 }
 
-#' @export
-#' @rdname drop_levels
-drop_levels.factor <- function(x, ...) {
-  chr <- as.character(x)
-  lvl <- levels(x) %wi% chr
-  struct(
-    match(chr, lvl),
-    class = c(if (is.ordered(x)) "ordered", "factor"),
-    levels = lvl
-  )
-}
-
 #' @export
 #' @rdname drop_levels
 drop_levels.fact <- function(x, ...) {
@@ -299,7 +325,17 @@ drop_levels.fact <- function(x, ...) {
   }
 }
 
-
+#' @export
+#' @rdname drop_levels
+drop_levels.factor <- function(x, ...) {
+  chr <- as.character(x)
+  lvl <- levels(x) %wi% chr
+  struct(
+    match(chr, lvl),
+    class = c(if (is.fact(x)) "fact", if (is.ordered(x)) "ordered", "factor"),
+    levels = lvl
+  )
+}
 
 # fact_na -----------------------------------------------------------------
 
@@ -338,6 +374,26 @@ fact_na <- function(x, remove = FALSE) {
   x
 }
 
+# fact_reverse ------------------------------------------------------------
+
+#' Fact reverse levels
+#'
+#' Reverse the levels of a `fact`
+#'
+#' @param x A `fact` object (or passed to [fact()])
+fact_reverse  <- function(x) {
+  x <- fact(x)
+  lvls <- flip(attr(x, "uniques"))
+  seq <- flip(seq_along(lvls))
+  na <- attr(x, "na")
+
+  if (na > 0) {
+    lvls <- c(lvls[-1L], lvls[1L])
+    seq <- c(seq[-1L], seq[1L])
+  }
+
+  new_fact(seq[x], levels = lvls, ordered = is.ordered(x), na = na)
+}
 
 # other methods -----------------------------------------------------------
 
@@ -356,6 +412,36 @@ as.double.fact <- function(x, ...) {
   as.double(as.integer(x))
 }
 
+#' @export
+as.character.fact <- function(x, ...) {
+  as.character(attr(x, "uniques")[x])
+}
+
+# because unique.factor() remakes factor
+# this won't drop levels
+#' @export
+unique.fact <- function(x, incomparables = FALSE, ...) {
+  att <- attributes(x)
+  struct(
+    unique(unclass(x)),
+    class = att$class,
+    levels = att$levels,
+    uniques = att$uniques,
+    na = att$na
+  )
+}
+
+#' @export
+as.Date.fact <- function(x, ...) {
+  as.Date(attr(x, "uniques"), ...)[x]
+}
+
+#' @export
+`[.fact` <- function(x, ...)  {
+  y <- NextMethod("[")
+  attributes(y) <- attributes(x)
+  y
+}
 
 # helpers -----------------------------------------------------------------
 
@@ -400,6 +486,7 @@ fact_values <- function(x) {
   if (!is.fact(x)) {
     stop("x must be a fact object", call. = FALSE)
   }
+
   attr(x, "uniques")[as.integer(x)]
 }
 
@@ -430,15 +517,8 @@ fact_coerce_levels <- function(x) {
     x[!nas] <- dates
   } else if (!anyNA(posix)) {
     x <- rep(NA_real_, n)
-
-
-    # Is this needed?
     stopifnot(all(!nas))
-    # if (any(nas)) {
-    #   x[!nas] <- as.double(posix)
-    # } else {
-      x[] <- as.double(posix)
-    # }
+    x[] <- as.double(posix)
     x <- as.POSIXct(
       x          = x,
       origin     = "1970-01-01",
