@@ -49,3 +49,13 @@ test_that("pseudo_id.pseudo_id() works", {
   id <- pseudo_id(x)
   expect_equal(pseudo_id(id), id)
 })
+
+test_that("snapshots", {
+  x <- c(
+    0.316596544580534,  0.838568194536492,   0.126674774102867,
+    0.657560844207183,  0.636712728533894,   0.571150240721181,
+    0.0811728567350656, 0.765485385898501,   0.562053531175479,
+    0.807950841495767,  0.00996402697637677, 0.825092894025147
+  )
+  expect_snapshot(pseudo_id(x))
+})
