@@ -50,5 +50,5 @@ test_that("examples", {
 test_that("struct() overwrites attributes", {
   x <- struct(list(), class = "foo", a = 1L)
   res <- struct(list(), class = "foo", a = 2L, .keep_attr = TRUE)
-  expect_identical(attr(res, "a", exact = TRUE), 2L)
+  expect_identical(exattr(res, "a"), 2L)
 })
